@@ -13,10 +13,8 @@ if __name__ == '__main__':
 
     dto = schema.load({
         'value': {
-            'provider': 'azure',
-            'name': 'example-secret',
-            'encoding': 'utf-8',
-            'opts': {'vault': 'unimatrixdev'}
+            'provider': 'config',
+            'opts': {'value': 'Inline secret'}
         }
     })
 
