@@ -1,7 +1,9 @@
 """Declares :class:`GoogleProvider`."""
+import marshmallow.fields
 from google.cloud import secretmanager
 
 from .base import Provider
+from .schema import BaseSchema
 
 
 class GoogleProvider(Provider):
@@ -9,6 +11,9 @@ class GoogleProvider(Provider):
     client = secretmanager.SecretManagerServiceAsyncClient()
     client_sync = secretmanager.SecretManagerServiceClient()
 
+    class schema_class(BaseSchema):
+        project = marshmallow.fields.String(required=True)
+
     def get_secret_version_sync(self, secret: 'Secret', version: str) -> bytes:
         response = self.client_sync.access_secret_version(
             name=self.client_sync.secret_version_path(
